==> ooo_dev_tools-0.32.1-py3-none-any.whl: ooodev/format/writer/direct/char/font/__init__.py <==
import uno
from ooo.dyn.awt.char_set import CharSetEnum as CharSetEnum
from ooo.dyn.awt.font_family import FontFamilyEnum as FontFamilyEnum
from ooo.dyn.awt.font_relief import FontReliefEnum as FontReliefEnum
from ooo.dyn.awt.font_slant import FontSlant as FontSlant
from ooo.dyn.awt.font_strikeout import FontStrikeoutEnum as FontStrikeoutEnum
from ooo.dyn.awt.font_underline import FontUnderlineEnum as FontUnderlineEnum
from ooo.dyn.awt.font_weight import FontWeightEnum as FontWeightEnum
from ooo.dyn.style.case_map import CaseMapEnum as CaseMapEnum
from ooo.dyn.table.shadow_format import ShadowFormat as ShadowFormat
from ooo.dyn.table.shadow_location import ShadowLocation as ShadowLocation

from ooodev.format.inner.direct.write.char.font.font import Font as Font
from ooodev.format.inner.direct.write.char.font.font_effects import FontEffects as FontEffects
from ooodev.format.inner.direct.write.char.font.font_effects import FontLine as FontLine
from ooodev.format.inner.direct.write.char.font.font_only import FontLang as FontLang
from ooodev.format.inner.direct.write.char.font.font_only import FontOnly as FontOnly
from ooodev.format.inner.direct.write.char.font.font_position import CharSpacingKind as CharSpacingKind
from ooodev.format.inner.direct.write.char.font.font_position import FontPosition as FontPosition
from ooodev.format.inner.direct.write.char.font.font_position import FontScriptKind as FontScriptKind
from ooodev.format.writer.style.char.kind.style_char_kind import StyleCharKind as StyleCharKind

__all__ = ["Font", "FontEffects", "FontOnly", "FontPosition"]

==> ooo_dev_tools-0.53.0-py3-none-any.whl: ooodev/format/writer/direct/char/font/__init__.py <==
from ooo.dyn.awt.char_set import CharSetEnum as CharSetEnum
from ooo.dyn.awt.font_family import FontFamilyEnum as FontFamilyEnum
from ooo.dyn.awt.font_relief import FontReliefEnum as FontReliefEnum
from ooo.dyn.awt.font_slant import FontSlant as FontSlant
from ooo.dyn.awt.font_strikeout import FontStrikeoutEnum as FontStrikeoutEnum
from ooo.dyn.awt.font_underline import FontUnderlineEnum as FontUnderlineEnum
from ooo.dyn.awt.font_weight import FontWeightEnum as FontWeightEnum
from ooo.dyn.style.case_map import CaseMapEnum as CaseMapEnum
from ooo.dyn.table.shadow_format import ShadowFormat as ShadowFormat
from ooo.dyn.table.shadow_location import ShadowLocation as ShadowLocation

from ooodev.format.inner.direct.write.char.font.font import Font as Font
from ooodev.format.inner.direct.write.char.font.font_effects import (
    FontEffects as FontEffects,
)
from ooodev.format.inner.direct.write.char.font.font_effects import FontLine as FontLine
from ooodev.format.inner.direct.write.char.font.font_only import FontLang as FontLang
from ooodev.format.inner.direct.write.char.font.font_only import FontOnly as FontOnly
from ooodev.format.inner.direct.write.char.font.font_position import (
    CharSpacingKind as CharSpacingKind,
)
from ooodev.format.inner.direct.write.char.font.font_position import (
    FontPosition as FontPosition,
)
from ooodev.format.inner.direct.write.char.font.font_position import (
    FontScriptKind as FontScriptKind,
)
from ooodev.format.writer.style.char.kind.style_char_kind import (
    StyleCharKind as StyleCharKind,
)

__all__ = ["Font", "FontEffects", "FontOnly", "FontPosition"]

import uno  # noqa # type: ignore
